summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Guerry <bzg@altern.org>2012-10-02 12:19:39 +0200
committerBastien Guerry <bzg@altern.org>2012-10-02 12:19:39 +0200
commit16e0730342725b7ff9a76d0a355dbc574ceced00 (patch)
treec87efaf7d951bb096b462edc54a092fe78b147df
parente1a01d50776d5c224fc27faf51369aeadb361fa4 (diff)
downloadorg-mode-16e0730342725b7ff9a76d0a355dbc574ceced00.tar.gz
Fix references to org-install.el.
Use org-loaddefs.el when needed. Update README_maintainer wrt this.
-rw-r--r--.gitignore2
-rw-r--r--Makefile2
-rw-r--r--README_maintainer8
-rw-r--r--contrib/lisp/org-track.el24
-rw-r--r--lisp/Makefile2
5 files changed, 14 insertions, 24 deletions
diff --git a/.gitignore b/.gitignore
index 32185ae..a9d73ad 100644
--- a/.gitignore
+++ b/.gitignore
@@ -30,7 +30,7 @@
orgcard_letter.tex
orgcard.txt
org
-org-install.el
+org-loaddefs.el
org-version.el
doc/org-version.inc
org-*.tar*
diff --git a/Makefile b/Makefile
index 9a96ffa..f95bcb2 100644
--- a/Makefile
+++ b/Makefile
@@ -28,7 +28,7 @@ help helpall::
$(info make all - ditto)
$(info make compile - build Org ELisp files)
$(info make single - build Org ELisp files, single Emacs per source)
- $(info make autoloads - create org-install.el to load Org in-place)
+ $(info make autoloads - create org-loaddefs.el to load Org in-place)
$(info make test - build Org ELisp files and run test suite)
helpall::
$(info make test-dirty - check without building first)
diff --git a/README_maintainer b/README_maintainer
index 1323217..04b0439 100644
--- a/README_maintainer
+++ b/README_maintainer
@@ -196,13 +196,9 @@ So the way I have been doing things with Emacs is this:
Careful: Copy /org.texi/ and /orgcard.tex/ into the right places,
and also copy the lisp files with *two exceptions*: Do *not* copy
- /org-colview-xemacs.el/ and /org-install.el/. The former does not
+ /org-colview-xemacs.el/ and /org-loaddefs.el/. The former does not
belong in Emacs. And the latter would actually be harmful because
- Emacs generates its own autoloads. The Emacs distribution contains
- an empty /org-install.el/, so that users can have =(require
- 'org-install)= in .emacs with no ill effects. So if you were to
- copy /org-install.el/, you would overwrite that empty placeholder
- file.
+ Emacs generates its own autoloads.
4. Generate the ChangeLog entries
diff --git a/lisp/Makefile b/lisp/Makefile
index 4bc86d4..bef1976 100644
--- a/lisp/Makefile
+++ b/lisp/Makefile
@@ -5,7 +5,7 @@ ifeq ($(MAKELEVEL), 0)
endif
LISPV = org-version.el
-LISPI = org-install.el
+LISPI = org-loaddefs.el
LISPA = $(LISPV) $(LISPI)
LISPF = $(filter-out $(LISPA),$(sort $(wildcard *.el)))
LISPC = $(filter-out $(LISPN:%el=%elc),$(LISPF:%el=%elc))
diff --git a/contrib/lisp/org-track.el b/contrib/lisp/org-track.el
index 1d12862..c3cb81c 100644
--- a/contrib/lisp/org-track.el
+++ b/contrib/lisp/org-track.el
@@ -32,6 +32,9 @@
;;
;;; Commentary:
;;
+;; WARNING: This library is obsolete, you should use the make targets
+;; to keep track of Org latest developments.
+;;
;; Download the latest development tarball, unpack and optionally compile it
;;
;; Usage:
@@ -46,15 +49,11 @@
;;
;; M-x org-track-update RET
-
-
(require 'url-parse)
(require 'url-handlers)
(autoload 'url-file-local-copy "url-handlers")
(autoload 'url-generic-parse-url "url-parse")
-
-
;;; Variables:
@@ -66,7 +65,7 @@ To use org-track, adjust `org-track-directory'.
Org will download the archived latest git version for you,
unpack it into that directory (i.e. a subdirectory
`org-mode/' is added), create the autoloads file
-`org-install.el' for you and, optionally, compile the
+`org-loaddefs.el' for you and, optionally, compile the
sources.
All you'll have to do is call `M-x org-track-update' from
time to time."
@@ -80,7 +79,7 @@ If that directory does not exist, it will be created."
(defcustom org-track-compile-sources t
"If `nil', never compile org-sources.
-Org will only create the autoloads file `org-install.el' for
+Org will only create the autoloads file `org-loaddefs.el' for
you then. If `t', compile the sources, too.
Note, that emacs preferes compiled elisp files over
non-compiled ones."
@@ -102,8 +101,6 @@ you need to unpack it."
"Remove org-latest.tar.gz after updates?"
:type 'boolean)
-
-
;;; Frontend
@@ -131,7 +128,6 @@ Also, generate autoloads and evtl. compile the sources."
(org-track-compile-org))
(error (message "%s" (error-message-string err)))))))
-
;;; tar related functions
@@ -171,7 +167,6 @@ subdirectory org-mode/ to DIRECTORY."
(if org-track-remove-package
(delete-file target))))
-
;;; Compile Org-mode sources
@@ -180,7 +175,7 @@ subdirectory org-mode/ to DIRECTORY."
;;;###autoload
(defun org-track-compile-org (&optional directory)
"Compile all *.el files that come with org-mode.
-Generate the autoloads file `org-install.el'.
+Generate the autoloads file `org-loaddefs.el'.
DIRECTORY is where the directory org-mode/ lives (i.e. the
parent directory of your local repo."
@@ -193,15 +188,15 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
"/")))
(add-to-list 'load-path directory)
(let ((list-of-org-files (file-expand-wildcards (concat directory "*.el"))))
;; create the org-install file
(require 'autoload)
- (setq esf/org-install-file (concat directory "org-install.el"))
+ (setq esf/org-install-file (concat directory "org-loaddefs.el"))
(find-file esf/org-install-file)
(erase-buffer)
(mapc (lambda (x)
(generate-file-autoloads x))
list-of-org-files)
- (insert "\n(provide (quote org-install))\n")
+ (insert "\n(provide (quote org-loaddefs))\n")
(save-buffer)
(kill-buffer)
(byte-compile-file esf/org-install-file t)
@@ -213,7 +208,6 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
(if org-track-compile-sources
(mapc (lambda (f) (byte-compile-file f)) list-of-org-files))))
-
(provide 'org-track)
;;; org-track.el ends here
@@ -193,15 +188,15 @@ DIRECTORY is where the directory org-mode/ lives (i.e. the
(add-to-list 'load-path directory)
(let ((list-of-org-files (file-expand-wildcards (concat directory "*.el"))))
- ;; create the org-install file
+ ;; create the org-loaddefs file
(require 'autoload)